@@ -13,7 +13,6 @@ from instagrapi.utils import dumps
 
 
 class HighlightMixin:
-
     def highlight_pk_from_url(self, url: str) -> str:
         """
         Get Highlight PK from URL
@@ -32,7 +31,7 @@ class HighlightMixin:
         --------
         https://www.instagram.com/stories/highlights/17895485201104054/ -> 17895485201104054
         """
-        assert '/highlights/' in url, 'URL must contain "/highlights/"'
+        assert "/highlights/" in url, 'URL must contain "/highlights/"'
         path = urlparse(url).path
         parts = [p for p in path.split("/") if p and p.isdigit()]
         return str(parts[0])
@@ -63,11 +62,10 @@ class HighlightMixin:
             "is_dark_mode": random.randint(0, 1),
             "will_sound_on": random.randint(0, 1),
         }
-        result = self.private_request(f"highlights/{user_id}/highlights_tray/", params=params)
-        return [
-            extract_highlight_v1(highlight)
-            for highlight in result.get("tray", [])
-        ]
+        result = self.private_request(
+            f"highlights/{user_id}/highlights_tray/", params=params
+        )
+        return [extract_highlight_v1(highlight) for highlight in result.get("tray", [])]
 
     def user_highlights(self, user_id: int, amount: int = 0) -> List[Highlight]:
         """
@@ -107,10 +105,10 @@ class HighlightMixin:
             "source": "profile",
             "_uid": str(self.user_id),
             "_uuid": self.uuid,
-            "user_ids": [highlight_id]
+            "user_ids": [highlight_id],
         }
-        result = self.private_request('feed/reels_media/', data)
-        data = result['reels']
+        result = self.private_request("feed/reels_media/", data)
+        data = result["reels"]
         if highlight_id not in data:
             raise HighlightNotFound(highlight_pk=highlight_pk, **data)
         return extract_highlight_v1(data[highlight_id])
@@ -131,7 +129,13 @@ class HighlightMixin:
         """
         return self.highlight_info_v1(highlight_pk)
 
-    def highlight_create(self, title: str, story_ids: List[str], cover_story_id: str = "", crop_rect: List[float] = [0.0, 0.21830457, 1.0, 0.78094524]) -> Highlight:
+    def highlight_create(
+        self,
+        title: str,
+        story_ids: List[str],
+        cover_story_id: str = "",
+        crop_rect: List[float] = [0.0, 0.21830457, 1.0, 0.78094524],
+    ) -> Highlight:
         """
         Create highlight
 
@@ -157,31 +161,42 @@ class HighlightMixin:
             "creation_id": str(int(time.time())),
             "_uid": str(self.user_id),
             "_uuid": self.uuid,
-            "cover": dumps({
-                "media_id": self.media_id(cover_story_id),
-                "crop_rect": dumps(crop_rect)
-            }),
+            "cover": dumps(
+                {
+                    "media_id": self.media_id(cover_story_id),
+                    "crop_rect": dumps(crop_rect),
+                }
+            ),
             "title": title,
-            "media_ids": dumps([self.media_id(sid) for sid in story_ids])
+            "media_ids": dumps([self.media_id(sid) for sid in story_ids]),
         }
         result = self.private_request("highlights/create_reel/", data=data)
-        return extract_highlight_v1(result['reel'])
+        return extract_highlight_v1(result["reel"])
 
-    def highlight_edit(self, highlight_pk: str, title: str = "", cover: Dict = {}, added_media_ids: List[str] = [], removed_media_ids: List[str] = []):
+    def highlight_edit(
+        self,
+        highlight_pk: str,
+        title: str = "",
+        cover: Dict = {},
+        added_media_ids: List[str] = [],
+        removed_media_ids: List[str] = [],
+    ):
         data = {
             "supported_capabilities_new": json.dumps(config.SUPPORTED_CAPABILITIES),
             "source": "self_profile",
             "_uid": str(self.user_id),
             "_uuid": self.uuid,
             "added_media_ids": dumps(added_media_ids),
-            "removed_media_ids": dumps(removed_media_ids)
+            "removed_media_ids": dumps(removed_media_ids),
         }
         if title:
             data["title"] = title
         if cover:
             data["cover"] = dumps(cover)
-        result = self.private_request(f"highlights/highlight:{highlight_pk}/edit_reel/", data=data)
-        return extract_highlight_v1(result['reel'])
+        result = self.private_request(
+            f"highlights/highlight:{highlight_pk}/edit_reel/", data=data
+        )
+        return extract_highlight_v1(result["reel"])
 
     def highlight_change_title(self, highlight_pk: str, title: str) -> Highlight:
         """
@@ -219,7 +234,9 @@ class HighlightMixin:
         cover = {"upload_id": str(upload_id), "crop_rect": "[0.0,0.0,1.0,1.0]"}
         return self.highlight_edit(highlight_pk, cover=cover)
 
-    def highlight_add_stories(self, highlight_pk: str, added_media_ids: List[str]) -> Highlight:
+    def highlight_add_stories(
+        self, highlight_pk: str, added_media_ids: List[str]
+    ) -> Highlight:
         """
         Add stories to highlight
 
@@ -236,7 +253,9 @@ class HighlightMixin:
         """
         return self.highlight_edit(highlight_pk, added_media_ids=added_media_ids)
 
-    def highlight_remove_stories(self, highlight_pk: str, removed_media_ids: List[str]) -> Highlight:
+    def highlight_remove_stories(
+        self, highlight_pk: str, removed_media_ids: List[str]
+    ) -> Highlight:
         """
         Remove stories from highlight
 
@@ -267,5 +286,7 @@ class HighlightMixin:
         bool
         """
         data = {"_uid": str(self.user_id), "_uuid": self.uuid}
-        result = self.private_request(f"highlights/highlight:{highlight_pk}/delete_reel/", data=data)
+        result = self.private_request(
+            f"highlights/highlight:{highlight_pk}/delete_reel/", data=data
+        )
         return result.get("status") == "ok"
