@@ -72,18 +72,24 @@ class PublicRequestMixin:
                 if self.delay_range:
                     random_delay(delay_range=self.delay_range)
                 return self._send_public_request(url, **kwargs)
-            except (ClientLoginRequired, ClientNotFoundError, ClientBadRequestError) as e:
+            except (
+                ClientLoginRequired,
+                ClientNotFoundError,
+                ClientBadRequestError,
+            ) as e:
                 raise e  # Stop retries
             # except JSONDecodeError as e:
             #     raise ClientJSONDecodeError(e, respones=self.last_public_response)
             except ClientError as e:
                 msg = str(e)
-                if all((
-                    isinstance(e, ClientConnectionError),
-                    "SOCKSHTTPSConnectionPool" in msg,
-                    "Max retries exceeded with url" in msg,
-                    "Failed to establish a new connection" in msg
-                )):
+                if all(
+                    (
+                        isinstance(e, ClientConnectionError),
+                        "SOCKSHTTPSConnectionPool" in msg,
+                        "Max retries exceeded with url" in msg,
+                        "Failed to establish a new connection" in msg,
+                    )
+                ):
                     raise e
                 if retries_count > iteration + 1:
                     time.sleep(retries_timeout)
@@ -168,7 +174,7 @@ class PublicRequestMixin:
     def public_a1_request(self, endpoint, data=None, params=None, headers=None):
         url = self.PUBLIC_API_URL + endpoint.lstrip("/")
         params = params or {}
-        params.update({"__a": 1, '__d': 'dis'})
+        params.update({"__a": 1, "__d": "dis"})
 
         response = self.public_request(
             url, data=data, params=params, headers=headers, return_json=True
